from django.test import TestCase
from kvideos.models import Video
from .models import TestModel
from django.core.exceptions import ValidationError
from django.template import TemplateSyntaxError, Template, Context

YOUTUBE_VALID_CODE = "dR14UepDQqk"
VIMEO_VALID_CODE = "45402998"

class KVideosModelTest(TestCase):
    def setUp(self):
        self.test = TestModel()
        self.test.save()
        self.valid_youtube_code = YOUTUBE_VALID_CODE
        self.invalid_youtube_code = "invalid"
        self.valid_vimeo_code = VIMEO_VALID_CODE
        self.invalid_vimeo_code = "invalid"

    def test_clean(self):
        self.assertEqual(None, Video(content_object=self.test, typ="youtube", code=self.valid_youtube_code).clean())
        with self.assertRaises(ValidationError):
            Video(content_object=self.test, typ="youtube", code=self.invalid_youtube_code).clean()

        self.assertEqual(None, Video(content_object=self.test, typ="vimeo", code=self.valid_vimeo_code).clean())
        with self.assertRaises(ValidationError):
            Video(content_object=self.test, typ="vimeo", code=self.invalid_vimeo_code).clean()

class KVideosTemplateTagTest(TestCase):
    def setUp(self):
        self.test = TestModel()
        self.test.save()
        self.youtube_video = Video(content_object=self.test, typ="youtube", code=YOUTUBE_VALID_CODE)
        self.youtube_video.save()
        self.vimeo_video = Video(content_object=self.test, typ="vimeo", code=VIMEO_VALID_CODE)
        self.vimeo_video.save()

    def test_embed_video(self):
        with_size_template = Template('{% load kvideos %}{% embed_video video 320x240 %}')
        no_size_template = Template('{% load kvideos %}{% embed_video video %}')

        rendered = with_size_template.render(Context({ 'video': self.youtube_video }))
        expected_result = '<iframe width="320" height="240" '
        expected_result += 'src="http://www.youtube.com/embed/dR14UepDQqk" '
        expected_result += 'frameborder="0" allowfullscreen>\n</iframe>\n'
        self.assertEqual(rendered,expected_result)

        rendered = with_size_template.render(Context({ 'video': self.vimeo_video }))
        expected_result = '<iframe src="http://player.vimeo.com/video/45402998?title=0&amp;byline=0&amp;portrait=0" '
        expected_result += 'width="320" height="240" frameborder="0" webkitAllowFullScreen '
        expected_result += 'mozallowfullscreen allowFullScreen>\n</iframe>\n'

        self.assertEqual(rendered,expected_result)

        rendered = no_size_template.render(Context({ 'video': self.youtube_video }))
        expected_result = '<iframe width="640" height="480" '
        expected_result += 'src="http://www.youtube.com/embed/dR14UepDQqk" '
        expected_result += 'frameborder="0" allowfullscreen>\n</iframe>\n'
        self.assertEqual(rendered,expected_result)

        rendered = no_size_template.render(Context({ 'video': self.vimeo_video }))
        expected_result = '<iframe src="http://player.vimeo.com/video/45402998?title=0&amp;byline=0&amp;portrait=0" '
        expected_result += 'width="640" height="480" frameborder="0" webkitAllowFullScreen '
        expected_result += 'mozallowfullscreen allowFullScreen>\n</iframe>\n'
        self.assertEqual(rendered,expected_result)

        with self.assertRaises(TemplateSyntaxError):
            # Bad object type test
            rendered = no_size_template.render(Context({ 'video': self.test }))

        with self.assertRaises(TemplateSyntaxError):
            bad_size_template = Template('{% load kvideos %}{% embed_video video 320x %}')

        with self.assertRaises(TemplateSyntaxError):
            bad_num_args_template = Template('{% load kvideos %}{% embed_video video 320x240 other %}')



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib.auth.models import User
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic
from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _
import urllib


SERVICE_CHOICES = [
    ('youtube', 'You Tube'),
    ('vimeo', 'Vimeo'),
]

class Video(models.Model):
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object = generic.GenericForeignKey('content_type', 'object_id')
    title = models.CharField(max_length=150, verbose_name=_(u'title'),
                             null=True, blank=True)
    description = models.TextField(verbose_name=_(u'description'), null=True,
                                   blank=True)
    typ = models.SlugField(max_length=25, choices=SERVICE_CHOICES,
                           verbose_name=_(u'type'), null=False, blank=False)
    code = models.CharField(max_length=100, verbose_name=_(u'code'),
                            null=False, blank=False)

    def clean(self):
        if self.typ == "youtube":
            validation_url = "http://gdata.youtube.com/feeds/api/videos/%s" % self.code
            conn = urllib.urlopen(validation_url)
            if conn.code != 200:
                raise ValidationError(_(u"%s id not found in YouTube" % self.code))
        elif self.typ == "vimeo":
            validation_url = "http://vimeo.com/api/v2/video/%s.json" % self.code 
            conn = urllib.urlopen(validation_url)
            if conn.code != 200:
                raise ValidationError(_(u"%s id not found in Vimeo" % self.code))
        else:
            raise ValidationError(_(u"%s is not a valid type of video." % self.typ))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import kvideos

setup(
    name = 'django-kvideos',
    version = ":versiontools:kvideos:",
    description = "Django application to add videos to models",
    long_description = "",
    keywords = 'django, visit, counter',
    author = 'Jesús Espino García',
    author_email = 'jespinog@gmail.com',
    url = 'https://github.com/kaleidos/django-kvideos',
    license = 'BSD',
    include_package_data = True,
    packages = find_packages(),
    package_data={
        'kvideos': [
            'templates/kvideos/*',
        ]
    },
    install_requires=[
        'distribute',
    ],
    setup_requires = [
        'versiontools >= 1.8',
    ],
    classifiers = [
        "Programming Language :: Python",
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ]
)



import os

AUTHNET_LOGIN_ID = ''
AUTHNET_TRANSACTION_KEY = ''

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3'
    },
}

SECRET_KEY = 'm+qa*7_8t-=17zt_)9gi)4g%6w*v$xxkh6rwrys*bn9su+5%du'

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.messages',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.staticfiles',
    'kvideos',
    'testing',
]

LANGUAGE_CODE = 'en'

LOGIN_URL = '/accounts/login/'

MANAGERS = []

MIDDLEWARE_CLASSES = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.common.CommonMiddleware',
]

ROOT_URLCONF = 'testing.urls'

SITE_ID = 1

TEMPLATE_DIRS = [os.path.join(os.path.dirname(__file__), 'templates')]

USE_I18N = True



from django import template
from ..models import Video
from ..settings import *

register = template.Library()

class EmbedVideoNode(template.Node):
    def __init__(self, video_object, width, height):
        self.video_object = template.Variable(video_object)
        self.width = width
        self.height = height

    def render(self, context):
        video = self.video_object.resolve(context)
    
        if not isinstance(video, Video):
            raise template.TemplateSyntaxError("embed_video tag first argument must be a Video object")

        video_template_context = {
            'code': video.code,
            'width': self.width,
            'height': self.height,
        }
        return template.loader.render_to_string("kvideos/%s.html" % video.typ, video_template_context)

def do_embed_video(parser, token):
    splited = token.split_contents()
    if len(splited) == 3:
        (tag_name, video_object, size) = splited
    elif len(splited) == 2:
        (tag_name, video_object) = splited
        size = KVIDEOS_DEFAULT_SIZE
    else:
        raise template.TemplateSyntaxError("embed_video tag requires two or three argument")

    if len(size.split("x")) != 2:
        raise template.TemplateSyntaxError("embed_video tag second argument should be in WIDTHxHEIGH format")

    try:
        width = int(size.split("x")[0])
        height = int(size.split("x")[1])
    except ValueError:
        raise template.TemplateSyntaxError("embed_video tag second argument should be in WIDTHxHEIGH format")

    return EmbedVideoNode(video_object, width, height)

register.tag('embed_video', do_embed_video)
